==> haskell-network-control-0.0.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-Hyu3crx4USUIDIziOUy5rS
key:                  network-control-0.0.2-Hyu3crx4USUIDIziOUy5rS
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  99d2f28f0bd462b2ffd55fc65f59c387
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-Hyu3crx4USUIDIziOUy5rS
depends:
    base-4.17.2.1 psqueues-0.2.8.1-5YdF0BXGKvl24ELtKydDjy
    unix-time-0.4.17-DuFqqgzo9URBCMDsHa3o0V

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-control-0.0.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.0.2
visibility:           public
id:                   network-control-0.0.2-1WoNF2Fcxn6H44uBDCmRbs
key:                  network-control-0.0.2-1WoNF2Fcxn6H44uBDCmRbs
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  684cfa7d188f872af86bde98df87a4fb
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/network-control-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.0.2-1WoNF2Fcxn6H44uBDCmRbs
depends:
    base-4.17.2.1 psqueues-0.2.8.1-E9v2yW4XfcrCUQT6uvm5KF
    unix-time-0.4.17-9xybMEtnTgVKohCUiVlkUy

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
